//Parametric Idler Pulley Bearing
//3/26/2020 By: David Bunch
//
//105zz 5x10x4.2
//625-2RS 5x16x5
//688Z 8x16x5
BB_OD = 10.0;                       //Diameter of Bearing
BB_ID = 5.0;                        //Inside Diameter of Bearing
                                    //(only used for visual overlay of bearing)
BB_Ht = 4.2;                        //Height of Bearing

Tol = .35;                          //Tolerance to add to each side of bearing
                                    //.35 = slightly loose fit
                                    //I like to be able to get bearings out,
                                    //so I use a looser fit.
                                    //.15 - .2 would be tighter fit
BBT_OD = BB_OD + Tol + Tol;         //Total Bearing Diameter for cutout
W_Thk = 2.0;                        //Wall Thickness between bearing & Where GT belt rides
Cent_Ht = 2.3;
HT_In = BB_Ht + Cent_Ht + BB_Ht;
ID = BB_OD - 2;                     //Inside Diameter to cut out
GT_OD = BBT_OD + W_Thk + W_Thk;     //Diameter of where GT belt Rides
FL_Ht_Bot = 2.0;                    //Flange Height at bottom
FL_Ht_Top = 2.0;                    //Flange Height at Top
FL_Wid = 2.0;                       //Flange width
FL_OD = GT_OD + FL_Wid + FL_Wid;    //Flange outside Diameter
GT_Ht = HT_In - FL_Ht_Top - FL_Ht_Bot;                        //Height GT Belt (6.5)
//Ht = FL_Ht_Bot + GT_Ht + FL_Ht_Top; //Total Height of Pulley Bearing
                      //Height of inside Center ridge between Bearings
CH_ID_Ht = .75;                     //Chamfer Inside Height
CH_ID = CH_ID_Ht + CH_ID_Ht;        //Chamfer Inside Diameter
CH_OD_Ht = 1.8;                     //Chamfer Outside Diameter Height
FL_T_D1 = FL_Ht_Top - CH_OD_Ht;     //Height of start of outside Taper
Section_Cut = 0;                    //Create Section Cut 0 = No, 1 = Yes
//
//Calculate Resolutions of cylinders
R1 = .7;                             //equals about length of arc segments
BBT_OD_Res = (round(((BBT_OD * 3.14)/4)/R1)*4);
BB_ID_Res = (round(((BB_ID * 3.14)/4)/R1)*4);
ID_Res = (round(((ID * 3.14)/4)/R1)*4);
GT_OD_Res = (round(((GT_OD * 3.14)/4)/R1)*4);
FL_OD_Res = (round(((FL_OD * 3.14)/4)/R1)*4);
//
echo(BBT_OD = BBT_OD);
echo(GT_OD = GT_OD);
echo(FL_OD = FL_OD);
echo(HT_In = HT_In);
//echo(Ht = Ht);
echo(GT_Ht = GT_Ht);
echo(BBT_OD_Res = BBT_OD_Res);
echo(BB_ID_Res = BB_ID_Res);
echo(ID_Res = ID_Res);
echo(GT_OD_Res = GT_OD_Res);
echo(FL_OD_Res = FL_OD_Res);
//
module DrawBearing()
{
//    translate([0,0,.3])
    color("gray",.7)
    difference()
    {
        cylinder(d=BB_OD,h=BB_Ht,$fn=BBT_OD_Res);
        translate([0,0,-.01])
        cylinder(d=BB_ID,h=BB_Ht+.02,$fn=BB_ID_Res);
        for (z = [-.01,BB_Ht-.3])
        {
            translate([0,0,z])
        difference()
        {
//            translate([0,0,-.01])
            cylinder(d=BB_OD-.8,h=.32,$fn=BBT_OD_Res);
            translate([0,0,-.02])
            cylinder(d=BB_ID+1.2,h=.34,$fn=BBT_OD_Res);
        }
    }
        
    }
}
Draw_Pulley();
%DrawBearing();
translate([0,0,HT_In-BB_Ht])
%DrawBearing();
module Draw_Pulley()
{
    difference()
    {
        union()
        {
            cylinder(d=FL_OD,h=FL_Ht_Bot,$fn=FL_OD_Res);    //Draw bottom Flange
            cylinder(d=GT_OD,h=HT_In,$fn=GT_OD_Res);           //Draw GT Belt cylinder
            translate([0,0,HT_In-FL_Ht_Top])
            cylinder(d1=GT_OD,d2=FL_OD,h=CH_OD_Ht,$fn=FL_OD_Res);   //Draw Tapered Top flange
            translate([0,0,HT_In-FL_T_D1])
            cylinder(d=FL_OD,h=FL_T_D1,$fn=FL_OD_Res);          //Draw Remainder of Top Flange
        }
        translate([0,0,-.01])
        cylinder(d=ID,h=HT_In+.02,$fn=ID_Res);     //Cut full Height of Inside Cut
        translate([0,0,-.01])
        cylinder(d=BBT_OD,h=BB_Ht+.01,$fn=BBT_OD_Res);  //Cutout for Bottom Bearing
        translate([0,0,HT_In-BB_Ht])
        cylinder(d=BBT_OD,h=BB_Ht+.01,$fn=BBT_OD_Res);  //Cutout for Top Bearing
        translate([0,0,-.01])
        cylinder(d1=BBT_OD + CH_ID,d2=BBT_OD,h=CH_ID_Ht+.01,$fn=BBT_OD_Res);    //Chamfer bottom Bearing
        translate([0,0,HT_In-CH_ID_Ht])
        cylinder(d1=BBT_OD,d2=BBT_OD + CH_ID,h=CH_ID_Ht+.01,$fn=BBT_OD_Res);    //Chamfer for Top Bearing
    
        translate([0,0,BB_Ht-.01])
        cylinder(d1=BBT_OD,d2=ID,h=CH_ID_Ht+.01,$fn=BBT_OD_Res);    //Chamfer middle Center
        if (Section_Cut == 1)
        {
            translate([-FL_OD,-FL_OD,-1])
            cube([FL_OD*2,FL_OD,HT_In+2]);
        }
    }
}